# NameV30Rc1

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_date** | [**CreatedDateV30Rc1**](CreatedDateV30Rc1.md) |  | [optional] 
**last_modified_date** | [**LastModifiedDateV30Rc1**](LastModifiedDateV30Rc1.md) |  | [optional] 
**given_names** | [**GivenNamesV30Rc1**](GivenNamesV30Rc1.md) |  | [optional] 
**family_name** | [**FamilyNameV30Rc1**](FamilyNameV30Rc1.md) |  | [optional] 
**credit_name** | [**CreditNameV30Rc1**](CreditNameV30Rc1.md) |  | [optional] 
**source** | [**SourceV30Rc1**](SourceV30Rc1.md) |  | [optional] 
**visibility** | **str** |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

